==> lxqt-panel-1.4.0-1.src.tar.gz: lxqt-panel-1.4.0/plugin-mount/translations/mount_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>Button</name>
    <message>
        <location filename="../button.cpp" line="38"/>
        <source>Removable media/devices manager</source>
        <translation>이동식 미디어/장비 관리 도구</translation>
    </message>
</context>
<context>
    <name>Configuration</name>
    <message>
        <location filename="../configuration.ui" line="14"/>
        <source>Removable Media Settings</source>
        <translation>이동식 미디어 설정</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="20"/>
        <source>Behaviour</source>
        <translation>동작</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="32"/>
        <source>When a device is connected:</source>
        <translation>장비를 연결했을 때:</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="42"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Trigger the following action when eject shortcut is pressed (&lt;span style=&quot; font-weight:600;&quot;&gt;XF86Eject&lt;/span&gt; by default)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;꺼내기 단축키를 누르면 다음 작업을 트리거합니다 (기본적으로 &lt;span style=&quot; font-weight:600;&quot;&gt;XF86Eject&lt;/span&gt;)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="45"/>
        <source>When eject button is pressed:</source>
        <translation>꺼내기 버튼을 누르면:</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="44"/>
        <source>Popup menu</source>
        <translation>메뉴 팝업</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="45"/>
        <source>Show info</source>
        <translation>정보 표시</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="46"/>
        <location filename="../configuration.cpp" line="51"/>
        <source>Do nothing</source>
        <translation>아무것도 안 하기</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="52"/>
        <source>Eject All Optical Drives</source>
        <translation>모든 광학 드라이브 꺼내기</translation>
    </message>
</context>
<context>
    <name>DeviceActionInfo</name>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="40"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>장비 &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt;에 연결했습니다.</translation>
    </message>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="45"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>장비 &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; 의 연결이 해제되었습니다.</translation>
    </message>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="50"/>
        <source>Removable media/devices manager</source>
        <translation>이동식 미디어/장비 관리 도구</translation>
    </message>
</context>
<context>
    <name>EjectActionOptical</name>
    <message>
        <location filename="../actions/ejectaction_optical.cpp" line="59"/>
        <source>Removable media/devices manager</source>
        <translation>이동식 미디어/장치 관리자</translation>
    </message>
    <message>
        <location filename="../actions/ejectaction_optical.cpp" line="59"/>
        <source>Ejected all optical drives</source>
        <translation>모든 광학 드라이브 배출됨</translation>
    </message>
</context>
<context>
    <name>LXQtMountPlugin</name>
    <message>
        <location filename="../lxqtmountplugin.cpp" line="79"/>
        <source>Removable media/devices manager: Global shortcut &apos;%1&apos; cannot be registered</source>
        <translation>이동식 미디어/장치 관리자: 전역 단축키 &apos;%1&apos; 등록할 수 없음</translation>
    </message>
    <message>
        <location filename="../lxqtmountplugin.cpp" line="116"/>
        <source>Eject removable media</source>
        <translation>이동식 미디어 꺼내기</translation>
    </message>
</context>
<context>
    <name>MenuDiskItem</name>
    <message>
        <location filename="../menudiskitem.cpp" line="153"/>
        <source>Mounting of &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; failed: %2</source>
        <translation>마운팅 &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; 실패: %2</translation>
    </message>
    <message>
        <location filename="../menudiskitem.cpp" line="155"/>
        <location filename="../menudiskitem.cpp" line="176"/>
        <source>Removable media/devices manager</source>
        <translation>이동식 미디어/장비 관리 도구</translation>
    </message>
    <message>
        <location filename="../menudiskitem.cpp" line="174"/>
        <source>Unmounting of &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; failed: %2</source>
        <translation>언마운팅 &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; 실패: %2</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <location filename="../popup.cpp" line="68"/>
        <source>No devices are available</source>
        <translation>사용할 장비가 없습니다</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.2.1-1.src.tar.gz: lxqt-panel-2.2.1/plugin-mount/translations/mount_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>Button</name>
    <message>
        <location filename="../button.cpp" line="38"/>
        <source>Removable media/devices manager</source>
        <translation>이동식 미디어/장비 관리 도구</translation>
    </message>
</context>
<context>
    <name>Configuration</name>
    <message>
        <location filename="../configuration.ui" line="14"/>
        <source>Removable Media Settings</source>
        <translation>이동식 미디어 설정</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="20"/>
        <source>Behavior</source>
        <translation>동작</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="32"/>
        <source>When a device is connected:</source>
        <translation>장비를 연결했을 때:</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="42"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Trigger the following action when eject shortcut is pressed (&lt;span style=&quot; font-weight:600;&quot;&gt;XF86Eject&lt;/span&gt; by default)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;꺼내기 단축키를 누르면 다음 작업을 트리거합니다 (기본적으로 &lt;span style=&quot; font-weight:600;&quot;&gt;XF86Eject&lt;/span&gt;)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../configuration.ui" line="45"/>
        <source>When eject button is pressed:</source>
        <translation>꺼내기 버튼을 누르면:</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="60"/>
        <source>Popup menu</source>
        <translation>메뉴 팝업</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="61"/>
        <source>Show info</source>
        <translation>정보 표시</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="62"/>
        <location filename="../configuration.cpp" line="64"/>
        <source>Do nothing</source>
        <translation>아무것도 안 하기</translation>
    </message>
    <message>
        <location filename="../configuration.cpp" line="65"/>
        <source>Eject All Optical Drives</source>
        <translation>모든 광학 드라이브 꺼내기</translation>
    </message>
</context>
<context>
    <name>DeviceActionInfo</name>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="40"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is connected.</source>
        <translation>장비 &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt;에 연결했습니다.</translation>
    </message>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="45"/>
        <source>The device &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; is removed.</source>
        <translation>장비 &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; 의 연결이 해제되었습니다.</translation>
    </message>
    <message>
        <location filename="../actions/deviceaction_info.cpp" line="50"/>
        <source>Removable media/devices manager</source>
        <translation>이동식 미디어/장비 관리 도구</translation>
    </message>
</context>
<context>
    <name>EjectActionOptical</name>
    <message>
        <location filename="../actions/ejectaction_optical.cpp" line="59"/>
        <source>Removable media/devices manager</source>
        <translation>이동식 미디어/장치 관리자</translation>
    </message>
    <message>
        <location filename="../actions/ejectaction_optical.cpp" line="59"/>
        <source>Ejected all optical drives</source>
        <translation>모든 광학 드라이브 배출됨</translation>
    </message>
</context>
<context>
    <name>LXQtMountPlugin</name>
    <message>
        <location filename="../lxqtmountplugin.cpp" line="79"/>
        <source>Removable media/devices manager: Global shortcut &apos;%1&apos; cannot be registered</source>
        <translation>이동식 미디어/장치 관리자: 전역 단축키 &apos;%1&apos; 등록할 수 없음</translation>
    </message>
    <message>
        <location filename="../lxqtmountplugin.cpp" line="116"/>
        <source>Eject removable media</source>
        <translation>이동식 미디어 꺼내기</translation>
    </message>
</context>
<context>
    <name>MenuDiskItem</name>
    <message>
        <location filename="../menudiskitem.cpp" line="156"/>
        <source>Mounting of &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; failed: %2</source>
        <translation>마운팅 &lt;b&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/b&gt; 실패: %2</translation>
    </message>
    <message>
        <location filename="../menudiskitem.cpp" line="158"/>
        <location filename="../menudiskitem.cpp" line="179"/>
        <source>Removable media/devices manager</source>
        <translation>이동식 미디어/장비 관리 도구</translation>
    </message>
    <message>
        <location filename="../menudiskitem.cpp" line="177"/>
        <source>Unmounting of &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; failed: %2</source>
        <translation>언마운팅 &lt;strong&gt;&lt;nobr&gt;&quot;%1&quot;&lt;/nobr&gt;&lt;/strong&gt; 실패: %2</translation>
    </message>
</context>
<context>
    <name>Popup</name>
    <message>
        <location filename="../popup.cpp" line="67"/>
        <source>No devices are available</source>
        <translation>사용할 장비가 없습니다</translation>
    </message>
</context>
</TS>
